Nodal Expansion Method
======================

This package implements the Nodal Expansion method (NEM) kernel
for solving the diffusion equation.


CMFD Current Calculator
-----------------------

.. automodule:: dorban.nem.cmfd_current_calculator
   :members:
   :undoc-members:
   :show-inheritance:

CMFD Iterations
---------------

.. automodule:: dorban.nem.cmfd_iterator
   :members:
   :undoc-members:
   :show-inheritance:

Leakage
-------

.. automodule:: dorban.nem.leakage
   :members:
   :undoc-members:
   :show-inheritance:

NEM equations right hand side
-----------------------------

.. automodule:: dorban.nem.nem_coupling_rhs
   :members:
   :undoc-members:
   :show-inheritance:

NEM equations matrices
----------------------

.. automodule:: dorban.nem.nem_matrices
   :members:
   :undoc-members:
   :show-inheritance:

Solve NEM
---------

.. automodule:: dorban.nem.solve_nem
   :members:
   :undoc-members:
   :show-inheritance:

NEM utils
---------

.. automodule:: dorban.nem.utils
   :members:
   :undoc-members:
   :show-inheritance:

